package cn.bunny.service.service.impl;

import cn.bunny.entity.order.Order;
import cn.bunny.service.mapper.OrderMapper;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.util.DigestUtils;

import java.math.BigDecimal;

@SpringBootTest
public class OrderServiceShardingTest {
    @Autowired
    private OrderMapper orderMapper;

    // 水平分片测试
    @Test
    void testShardingOrder() {
        double random = Math.random();
        String md5DigestAsHex = DigestUtils.md5DigestAsHex(String.valueOf(random).getBytes());

        Order order = new Order();
        order.setOrderNo(md5DigestAsHex.substring(0, 6));
        order.setUserId(1L);
        order.setAmount(new BigDecimal(100));

        orderMapper.insert(order);
    }

    // 分库测试
    @Test
    void testInsertOrderStrategy() {
        for (long i = 0; i < 4; i++) {
            double random = Math.random();
            String md5DigestAsHex = DigestUtils.md5DigestAsHex(String.valueOf(random).getBytes());

            Order order = new Order();
            order.setOrderNo(md5DigestAsHex.substring(0, 6));
            order.setUserId(i);
            order.setAmount(new BigDecimal(100));

            orderMapper.insert(order);
        }
    }


    // 分库测试
    @Test
    void testInsertOrderStrategy2() {
        for (long i = 4; i < 8; i++) {
            double random = Math.random();
            String md5DigestAsHex = DigestUtils.md5DigestAsHex(String.valueOf(random).getBytes());

            Order order = new Order();
            order.setOrderNo(md5DigestAsHex.substring(0, 6));
            order.setUserId(i);
            order.setAmount(new BigDecimal(100));

            orderMapper.insert(order);
        }
    }

    // 分库分别测试
    @Test
    void testInsertOrderStrategy3() {
        for (long i = 5; i < 9; i++) {

            Order order = new Order();
            order.setOrderNo("ATGUIGU" + i);
            order.setUserId(2L);
            order.setAmount(new BigDecimal(100));
            orderMapper.insert(order);
        }
    }
}
