package cn.bunny.stream;

import org.junit.jupiter.api.Test;

import java.math.BigInteger;
import java.util.List;
import java.util.stream.Stream;

public class StreamTest {
    @Test
    void testStream() {
        // 产生随机数字流，会一直输出
        Stream<Double> stream = Stream.generate(Math::random);
        stream.forEach(System.out::println);
    }

    @Test
    void internalStream() {
        // 一直循环添加
        Stream<BigInteger> stream = Stream.iterate(BigInteger.ZERO, n -> n.add(BigInteger.ONE));
        stream.forEach(System.out::println);
    }

    @Test
    void testGeneratorLimit() {
        // 创建指定长度随机数
        List<Double> list = Stream.generate(Math::random).limit(10).toList();
        list.forEach(System.out::println);

        // 创建不好喊任何元素的流
        Stream<Object> empty = Stream.empty();
        empty.forEach(System.out::println);

        // 创建一个给定值的流
        Stream<Integer> integerStream = Stream.of(1, 2, 3, 4, 5, 6);
        integerStream.forEach(System.out::println);

        // 使用 ofNullable 创建一个流，如果值为 null 则创建一个空流
        Stream<String> stream = Stream.ofNullable("hello");
        stream.forEach(System.out::println);
    }
}
